@@ -25,7 +25,6 @@
 #define NETWORKMANAGERQT_DEVICE_H
 
 #include <QObject>
-#include <QtGlobal>
 #include <QSharedPointer>
 
 #include <networkmanagerqt/networkmanagerqt_export.h>
@@ -58,7 +57,6 @@ class NETWORKMANAGERQT_EXPORT Device : public QObject
     Q_PROPERTY(QString firmwareVersion READ firmwareVersion)
     Q_PROPERTY(QVariant genericCapabilities READ capabilitiesV)
     Q_PROPERTY(QHostAddress ipV4Address READ ipV4Address)
-    Q_PROPERTY(uint InterfaceFlags READ interfaceFlags)
     Q_PROPERTY(bool managed READ managed)
     Q_PROPERTY(uint mtu READ mtu)
     Q_PROPERTY(bool nmPluginMissing READ nmPluginMissing)
@@ -170,7 +168,15 @@ public:
         IpTunnel,                               /**< IP Tunneling Device @since 1.2.0 */
         VxLan,                                  /**< Vxlan Device @since 1.2.0 */
         MacSec,                                 /**< MacSec Device @since 1.6.0 */
-        Dummy                                   /**< Dummy Device @since 1.8.0 */
+        Dummy,                                  /**< Dummy Device @since 1.8.0 */
+        Ppp,                                    /**< Ppp Device @since 1.10 */
+        OvsInterface,                           /**< OvsInterface Device @since 1.10 */
+        OvsPort,                                /**< OvsPort Device @since 1.10 */
+        OvsBridge,                              /**< OvsBridge Device @since 1.10 */
+        Wpan,                                   /**< Wpan Device @since 1.14 */
+        Lowpan,                                 /**< Lowpan Device @since 1.14 */
+        WireGuard,                              /**< WireGuard Device @since 1.14 */
+        WifiP2P                                 /**< WifiP2P Device @since 1.16 */
     };
     Q_ENUM(Type)
     Q_DECLARE_FLAGS(Types, Type)
@@ -236,6 +242,10 @@ public:
      * The firmware version.
      */
     QString firmwareVersion() const;
+    /**
+     * Reapplies connection settings on the interface.
+     */
+    QDBusPendingReply<> reapplyConnection(const NMVariantMapMap &connection, qulonglong version_id, uint flags);
     /**
      * Disconnects a device and prevents the device from automatically
      * activating further connections without user intervention.
@@ -323,10 +333,6 @@ public:
      * Is the device currently being managed by NetworkManager?
      */
     bool managed() const;
-    /**
-      * The up or down flag for the device
-      */
-    uint interfaceFlags() const;
     /**
      * Is the firmware needed by the device missing?
      */
@@ -512,10 +518,6 @@ Q_SIGNALS:
      * Emitted when the managed state of this network has changed.
      */
     void managedChanged();
-    /**
-      * Emitted when the up or down state of the device changed
-      */
-    void interfaceFlagsChanged();
 
     /**
      * Emitted when the physical port ID changes.
