@@ -24,7 +24,6 @@
 #include <QObject>
 
 #include <QDBusObjectPath>
-#include <QDBusPendingReply>
 
 #include "../generictypes.h"
 #include "../device.h"
@@ -36,7 +35,7 @@ class WiredDevice : public Device
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.fakenetwork.Device.Wired")
 public:
-    explicit WiredDevice(QObject *parent = 0);
+    explicit WiredDevice(QObject *parent = nullptr);
     virtual ~WiredDevice();
 
     Q_PROPERTY(bool Carrier READ carrier)
@@ -54,7 +53,7 @@ public:
     void setHwAddress(const QString &hwAddress);
     void setPermanentHwAddress(const QString &permanentHwAddress);
     void setSpeed(uint speed);
-    void setState(uint state) Q_DECL_OVERRIDE;
+    void setState(uint state) override;
 
 Q_SIGNALS:
     Q_SCRIPTABLE void PropertiesChanged(const QVariantMap &properties);
