@@ -35,6 +35,7 @@
 #include "gsmsetting.h"
 #include "cdmasetting.h"
 #include "infinibandsetting.h"
+#include "iptunnelsetting.h"
 #include "ipv4setting.h"
 #include "ipv6setting.h"
 #include "pppsetting.h"
@@ -44,56 +45,23 @@
 #include "vlansetting.h"
 #include "vpnsetting.h"
 #include "wimaxsetting.h"
+#include "wireguardsetting.h"
 
 #undef signals
-#if NM_CHECK_VERSION(1, 0, 0)
 #include <libnm/NetworkManager.h>
-#else
-#include <nm-setting-adsl.h>
-#include <nm-setting-bond.h>
-#include <nm-setting-bluetooth.h>
-#include <nm-setting-bridge.h>
-#include <nm-setting-cdma.h>
-#include <nm-setting-connection.h>
-#include <nm-setting-gsm.h>
-#include <nm-setting-infiniband.h>
-#include <nm-setting-olpc-mesh.h>
-#include <nm-setting-pppoe.h>
-#include <nm-setting-vlan.h>
-#include <nm-setting-vpn.h>
-#include <nm-setting-wimax.h>
-#include <nm-setting-wired.h>
-#include <nm-setting-wireless.h>
-#include <nm-setting-team.h>
-#include <nm-setting-generic.h>
-#define signals Q_SIGNALS
-
-#define NM_SETTING_CONNECTION_AUTOCONNECT_PRIORITY "autoconnect-priority"
-#define NM_SETTING_CONNECTION_AUTOCONNECT_SLAVES "autoconnect-slaves"
-
-#endif
-
-#if !NM_CHECK_VERSION(1, 0, 6)
-#define NM_SETTING_CONNECTION_METERED "metered"
-#endif
-
-#if !NM_CHECK_VERSION(1, 2, 0)
-#define NM_SETTING_TUN_SETTING_NAME "tun"
-#define NM_SETTING_CONNECTION_LLDP "lldp"
-#endif
-
-#if !NM_CHECK_VERSION(1, 4, 0)
-#define NM_SETTING_CONNECTION_STABLE_ID "stable-id"
-#endif
 
 #if !NM_CHECK_VERSION(1, 6, 0)
 #define NM_SETTING_CONNECTION_AUTOCONNECT_RETRIES "autoconnect-retries"
 #endif
 
+#if !NM_CHECK_VERSION(1, 16, 0)
+#define NM_SETTING_WIREGUARD_SETTING_NAME "wireguard"
+#endif
+
 #include "teamsetting.h"
 #include "genericsetting.h"
 
-#include <QtCore/QUuid>
+#include <QUuid>
 
 namespace NetworkManager {
     extern int checkVersion(const int x, const int y, const int z);
@@ -230,6 +198,16 @@ void NetworkManager::ConnectionSettingsPrivate::initSettings(NMBluetoothCapabili
         addSetting(Setting::Ptr(new Ipv4Setting()));
         addSetting(Setting::Ptr(new Ipv6Setting()));
         break;
+    case ConnectionSettings::IpTunnel:
+        addSetting(Setting::Ptr(new IpTunnelSetting()));
+        addSetting(Setting::Ptr(new Ipv4Setting()));
+        addSetting(Setting::Ptr(new Ipv6Setting()));
+        break;
+    case ConnectionSettings::WireGuard:
+        addSetting(Setting::Ptr(new WireGuardSetting()));
+        addSetting(Setting::Ptr(new Ipv4Setting()));
+        addSetting(Setting::Ptr(new Ipv6Setting()));
+        break;
     case ConnectionSettings::Unknown:
     default:
         break;
@@ -346,6 +324,16 @@ void NetworkManager::ConnectionSettingsPrivate::initSettings(const NetworkManage
         addSetting(connectionSettings->setting(Setting::Ipv4));
         addSetting(connectionSettings->setting(Setting::Ipv6));
         break;
+    case ConnectionSettings::IpTunnel:
+        addSetting(connectionSettings->setting(Setting::IpTunnel));
+        addSetting(connectionSettings->setting(Setting::Ipv4));
+        addSetting(connectionSettings->setting(Setting::Ipv6));
+        break;
+    case ConnectionSettings::WireGuard:
+        addSetting(connectionSettings->setting(Setting::WireGuard));
+        addSetting(connectionSettings->setting(Setting::Ipv4));
+        addSetting(connectionSettings->setting(Setting::Ipv6));
+        break;
     case ConnectionSettings::Unknown:
     default:
         break;
@@ -390,6 +378,10 @@ NetworkManager::ConnectionSettings::ConnectionType NetworkManager::ConnectionSet
         type = Generic;
     } else if (typeString == QLatin1String(NM_SETTING_TUN_SETTING_NAME)) {
         type = Tun;
+    } else if (typeString == QLatin1String(NM_SETTING_IP_TUNNEL_SETTING_NAME)) {
+        type = IpTunnel;
+    } else if (typeString == QLatin1String(NM_SETTING_WIREGUARD_SETTING_NAME)) {
+        type = WireGuard;
     }
 
     return type;
@@ -451,6 +443,12 @@ QString NetworkManager::ConnectionSettings::typeAsString(NetworkManager::Connect
     case Tun:
         typeString = QLatin1String(NM_SETTING_TUN_SETTING_NAME);
         break;
+    case IpTunnel:
+        typeString = QLatin1String(NM_SETTING_IP_TUNNEL_SETTING_NAME);
+        break;
+    case WireGuard:
+        typeString = QLatin1String(NM_SETTING_WIREGUARD_SETTING_NAME);
+        break;
     default:
         break;
     };
@@ -527,7 +525,11 @@ void NetworkManager::ConnectionSettings::fromMap(const NMVariantMapMap &map)
     if (connectionSettings.contains(QLatin1String(NM_SETTING_CONNECTION_PERMISSIONS))) {
         QStringList permissions = connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_PERMISSIONS)).toStringList();
         Q_FOREACH (const QString & permission, permissions) {
-            const QStringList split = permission.split(QLatin1String(":"), QString::KeepEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            const QStringList split = permission.split(QLatin1Char(':'), QString::KeepEmptyParts);
+#else
+            const QStringList split = permission.split(QLatin1Char(':'), Qt::KeepEmptyParts);
+#endif
             addToPermissions(split.at(1), split.at(2));
         }
     }
@@ -542,9 +544,7 @@ void NetworkManager::ConnectionSettings::fromMap(const NMVariantMapMap &map)
 
     if (connectionSettings.contains(QLatin1String(NM_SETTING_CONNECTION_TIMESTAMP))) {
         const int timestamp = connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_TIMESTAMP)).toInt();
-        QDateTime dateTime;
-        dateTime.setTime_t(timestamp);
-        setTimestamp(dateTime);
+        setTimestamp(QDateTime::fromSecsSinceEpoch(timestamp));
     }
 
     if (connectionSettings.contains(QLatin1String(NM_SETTING_CONNECTION_READ_ONLY))) {
@@ -644,7 +644,7 @@ NMVariantMapMap NetworkManager::ConnectionSettings::toMap() const
     }
 
     if (timestamp().isValid()) {
-        connectionSetting.insert(QLatin1String(NM_SETTING_CONNECTION_TIMESTAMP), timestamp().toTime_t());
+        connectionSetting.insert(QLatin1String(NM_SETTING_CONNECTION_TIMESTAMP), timestamp().toSecsSinceEpoch());
     }
 
     if (readOnly()) {
@@ -1017,7 +1017,7 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::ConnectionS
     dbg.nospace() << NM_SETTING_CONNECTION_PERMISSIONS << ": " << setting.permissions() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_AUTOCONNECT << ": " << setting.autoconnect() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_AUTOCONNECT_PRIORITY << ": " << setting.autoconnectPriority() << '\n';
-    dbg.nospace() << NM_SETTING_CONNECTION_TIMESTAMP << ": " << setting.timestamp().toTime_t() << '\n';
+    dbg.nospace() << NM_SETTING_CONNECTION_TIMESTAMP << ": " << setting.timestamp().toSecsSinceEpoch() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_READ_ONLY << ": " << setting.readOnly() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_ZONE << ": " << setting.zone() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_MASTER << ": " << setting.master() << '\n';
@@ -1103,6 +1103,12 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::ConnectionS
         case Setting::Tun:
             dbg.nospace() << *(settingPtr.staticCast<NetworkManager::TunSetting>().data());
             break;
+        case Setting::IpTunnel:
+            dbg.nospace() << *(settingPtr.staticCast<NetworkManager::IpTunnelSetting>().data());
+            break;
+        case Setting::WireGuard:
+            dbg.nospace() << *(settingPtr.staticCast<NetworkManager::WireGuardSetting>().data());
+            break;
         default:
             dbg.nospace() << *settingPtr.data();
         }
