@@ -1,5 +1,5 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    Copyright 2012-2019  Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -29,9 +29,8 @@
 #include <libnm/NetworkManager.h>
 #define signals Q_SIGNALS
 
-#include <QtCore/QVariantMap>
-#include <QtCore/QStringList>
-#include <QtCore/QFlags>
+#include <QVariantMap>
+#include <QStringList>
 #include <QSharedPointer>
 
 namespace NetworkManager
@@ -71,7 +70,21 @@ public:
         BridgePort,
         Team,
         Generic,
-        Tun
+        Tun,
+        Vxlan,
+        IpTunnel,
+        Proxy,
+        User,
+        OvsBridge,
+        OvsInterface,
+        OvsPatch,
+        OvsPort,
+        Match,
+        Tc,
+        TeamPort,
+        Macsec,
+        Dcb,
+        WireGuard
     };
 
     enum SecretFlagType {
