@@ -19,6 +19,8 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QRegularExpression>
+
 #include "utils.h"
 #include "time.h"
 
@@ -76,9 +78,9 @@ QByteArray NetworkManager::macAddressFromString(const QString &s)
 
 bool NetworkManager::macAddressIsValid(const QString &macAddress)
 {
-    QRegExp macAddressCheck = QRegExp("([a-fA-F0-9][a-fA-F0-9]:){5}[0-9a-fA-F][0-9a-fA-F]");
+    QRegularExpression macAddressCheck(QStringLiteral("([a-fA-F0-9][a-fA-F0-9]:){5}[0-9a-fA-F][0-9a-fA-F]"));
 
-    return macAddress.contains(macAddressCheck);
+    return macAddressCheck.match(macAddress).hasMatch();
 }
 
 bool NetworkManager::macAddressIsValid(const QByteArray &macAddress)
@@ -167,7 +169,7 @@ bool NetworkManager::deviceSupportsApCiphers(NetworkManager::WirelessDevice::Cap
     return (havePair && haveGroup);
 }
 
-// Keep this in sync with NetworkManager/libnm-util/nm-utils.c:nm_utils_security_valid()
+// Keep this in sync with NetworkManager/libnm-core/nm-utils.c:nm_utils_security_valid()
 bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::WirelessDevice::Capabilities interfaceCaps, bool haveAp, bool adhoc, NetworkManager::AccessPoint::Capabilities apCaps, NetworkManager::AccessPoint::WpaFlags apWpa, NetworkManager::AccessPoint::WpaFlags apRsn)
 {
     bool good = true;
@@ -184,6 +186,8 @@ bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::
             if (interfaceCaps.testFlag(NetworkManager::WirelessDevice::Wep40) ||
                     interfaceCaps.testFlag(NetworkManager::WirelessDevice::Wep104)) {
                 return true;
+            } else {
+                return false;
             }
         }
 
@@ -205,7 +209,6 @@ bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::
 //                 return true;
 //             }
 //         }
-        return false;
     }
 
     switch (type) {
@@ -254,21 +257,15 @@ bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::
         }
         break;
     case WpaPsk:
+        if (adhoc) {
+            return false;
+        }
+
         if (!interfaceCaps.testFlag(NetworkManager::WirelessDevice::Wpa)) {
             return false;
         }
         if (haveAp) {
-            /* Ad-Hoc WPA APs won't necessarily have the PSK flag set */
-            if (adhoc) {
-                if (apWpa.testFlag(NetworkManager::AccessPoint::GroupTkip) &&
-                        interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
-                    return true;
-                }
-                if (apWpa.testFlag(NetworkManager::AccessPoint::GroupCcmp) &&
-                        interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
-                    return true;
-                }
-            } else if (apWpa.testFlag(NetworkManager::AccessPoint::KeyMgmtPsk)) {
+            if (apWpa.testFlag(NetworkManager::AccessPoint::KeyMgmtPsk)) {
                 if (apWpa.testFlag(NetworkManager::AccessPoint::PairTkip) &&
                         interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
                     return true;
@@ -286,16 +283,25 @@ bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::
             return false;
         }
         if (haveAp) {
-            /* Ad-Hoc WPA APs won't necessarily have the PSK flag set */
-            if (apRsn.testFlag(NetworkManager::AccessPoint::KeyMgmtPsk) || adhoc) {
-                if (apRsn.testFlag(NetworkManager::AccessPoint::PairTkip) &&
-                        interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
-                    return true;
+            if (adhoc) {
+                if (!interfaceCaps.testFlag(NetworkManager::WirelessDevice::IBSSRsn)) {
+                    return false;
                 }
                 if (apRsn.testFlag(NetworkManager::AccessPoint::PairCcmp) &&
                         interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
                     return true;
                 }
+            } else {
+                if (apRsn.testFlag(NetworkManager::AccessPoint::KeyMgmtPsk)) {
+                    if (apRsn.testFlag(NetworkManager::AccessPoint::PairTkip) &&
+                            interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
+                        return true;
+                    }
+                    if (apRsn.testFlag(NetworkManager::AccessPoint::PairCcmp) &&
+                            interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
+                        return true;
+                    }
+                }
             }
             return false;
         }
@@ -339,26 +345,29 @@ bool NetworkManager::securityIsValid(WirelessSecurityType type, NetworkManager::
             return false;
         }
         if (haveAp) {
-            if (!interfaceCaps.testFlag(NetworkManager::WirelessDevice::IBSSRsn)) {
-                return false;
-            }
-            if (apRsn.testFlag(NetworkManager::AccessPoint::PairCcmp) &&
-                    interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
-                return true;
-            }
-        } else {
-            if (apRsn.testFlag(NetworkManager::AccessPoint::KeyMgmtSAE)) {
-                if (apRsn.testFlag(NetworkManager::AccessPoint::PairTkip) &&
-                        interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
-                    return true;
+            if (adhoc) {
+                if (!interfaceCaps.testFlag(NetworkManager::WirelessDevice::IBSSRsn)) {
+                    return false;
                 }
                 if (apRsn.testFlag(NetworkManager::AccessPoint::PairCcmp) &&
                         interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
                     return true;
                 }
+            } else {
+                if (apRsn.testFlag(NetworkManager::AccessPoint::KeyMgmtSAE)) {
+                    if (apRsn.testFlag(NetworkManager::AccessPoint::PairTkip) &&
+                            interfaceCaps.testFlag(NetworkManager::WirelessDevice::Tkip)) {
+                        return true;
+                    }
+                    if (apRsn.testFlag(NetworkManager::AccessPoint::PairCcmp) &&
+                            interfaceCaps.testFlag(NetworkManager::WirelessDevice::Ccmp)) {
+                        return true;
+                    }
+                }
             }
             return false;
         }
+        break;
     default:
         good = false;
         break;
@@ -471,6 +480,8 @@ NetworkManager::WirelessSecurityType NetworkManager::securityTypeFromConnectionS
             return WpaEap;
         }
         return Wpa2Eap;
+    } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::SAE) {
+        return SAE;
     }
 
     return NoneSecurity;
